//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[Daisangen](-daisangen.md)

# Daisangen

[common]\
val [Daisangen](-daisangen.md): [Yaku](../-yaku/index.md)

大三元
